import { createWrapper, axios } from 'app/test/vitest/helper';
import FilterItemForm from 'src/components/FilterItemForm.vue';
import { vi, beforeAll, describe, expect, it } from 'vitest';

describe('FilterItemForm', () => {
    let vm;
    let wrapper;

    beforeAll(() => {
        wrapper = createWrapper(FilterItemForm, {
            props: {
                url: 'Items/withName',
            },
        });
        vm = wrapper.vm;
        wrapper = wrapper.wrapper;

        vi.spyOn(axios, 'get').mockResolvedValue({
            data: [
                {
                    id: 999996,
                    name: 'bolas de madera',
                    size: 2,
                    inkFk: null,
                    producerFk: null,
                },
            ],
        });
    });

    it('should filter data and populate tableRows for table display', async () => {
        vm.itemFilterParams.name = 'bolas de madera';

        await vm.onSubmit();

        const expectedFilter = {
            include: [
                { relation: 'producer', scope: { fields: ['name'] } },
                { relation: 'ink', scope: { fields: ['name'] } },
            ],
            where: {"name":{"like":"%bolas de madera%"}},
        };
        
        expect(axios.get).toHaveBeenCalledWith('Items/withName', {
            params: { filter: JSON.stringify(expectedFilter) },
        });

        expect(vm.tableRows).toEqual([
            {
                id: 999996,
                name: 'bolas de madera',
                size: 2,
                inkFk: null,
                producerFk: null,
            },
        ]);
    });

    it('should handle an empty itemFilterParams correctly', async () => {
        vm.itemFilterParams.name = null;
        vm.itemFilterParams = {};

        await vm.onSubmit();

        const expectedFilter = {
            include: [
                { relation: 'producer', scope: { fields: ['name'] } },
                { relation: 'ink', scope: { fields: ['name'] } },
            ],
            where: {},
        };

        expect(axios.get).toHaveBeenCalledWith('Items/withName', {
            params: { filter: JSON.stringify(expectedFilter) },
        });
    });

    it('should emit "itemSelected" with the correct id and close the form', () => {
        vm.selectItem({ id: 12345 });
        expect(wrapper.emitted('itemSelected')[0]).toEqual([12345]);
    });
});