import { describe, it, expect, vi, afterEach } from 'vitest';
import axios from 'axios';
import { getAddresses } from 'src/pages/Customer/composables/getAddresses';

vi.mock('axios');

describe('getAddresses', () => {
    afterEach(() => {
        vi.clearAllMocks();
    });

    it('should fetch addresses with correct parameters for a valid clientId', async () => {
        const clientId = '12345';

        await getAddresses(clientId);

        expect(axios.get).toHaveBeenCalledWith(`Clients/${clientId}/addresses`, {
            params: {
                filter: JSON.stringify({
                    fields: ['nickname', 'street', 'city', 'id'],
                    where: { isActive: true },
                    order: 'nickname ASC',
                }),
            },
        });
    });

    it('should return undefined when clientId is not provided', async () => {
        await getAddresses(undefined);

        expect(axios.get).not.toHaveBeenCalled();
    });
});