import { describe, it, expect, vi, afterEach } from 'vitest';
import axios from 'axios';
import { getClient } from 'src/pages/Customer/composables/getClient';

vi.mock('axios');

describe('getClient', () => {
    afterEach(() => {
        vi.clearAllMocks();
    });

    const generateParams = (clientId) => ({
        params: {
            filter: JSON.stringify({
                include: {
                    relation: 'defaultAddress',
                    scope: {
                        fields: ['id', 'agencyModeFk'],
                    },
                },
                where: { id: clientId },
            }),
        },
    });

    it('should fetch client data with correct parameters for a valid clientId', async () => {
        const clientId = '12345';

        await getClient(clientId);

        expect(axios.get).toHaveBeenCalledWith('Clients', generateParams(clientId));
    });

    it('should return undefined when clientId is not provided', async () => {
        const clientId = undefined;

        await getClient(clientId);

        expect(axios.get).toHaveBeenCalledWith('Clients', generateParams(clientId));
    });
});
