import { describe, it, expect, vi, afterEach } from 'vitest';
import axios from 'axios';
import { getAgencies } from 'src/pages/Route/Agency/composables/getAgencies';

vi.mock('axios');

describe('getAgencies', () => {
    afterEach(() => {
        vi.clearAllMocks();
    });

    const generateParams = (formData) => ({
        params: {
            warehouseFk: formData.warehouseId,
            addressFk: formData.addressId,
            landed: formData.landed,
        },
    });

    it('should fetch agencies data with correct parameters for valid formData', async () => {
        const formData = {
            warehouseId: '123',
            addressId: '456',
            landed: 'true',
        };

        await getAgencies(formData);

        expect(axios.get).toHaveBeenCalledWith('Agencies/getAgenciesWithWarehouse', generateParams(formData));
    });

    it('should not call API when formData is missing required landed field', async () => {
        const formData = { warehouseId: '123', addressId: '456' };

        await getAgencies(formData);

        expect(axios.get).not.toHaveBeenCalled();
    });

    it('should not call API when formData is missing required addressId field', async () => {
        const formData = { warehouseId: '123', landed: 'true' };

        await getAgencies(formData);

        expect(axios.get).not.toHaveBeenCalled();
    });

    it('should not call API when formData is missing required warehouseId field', async () => {
        const formData = { addressId: '456', landed: 'true' };

        await getAgencies(formData);

        expect(axios.get).not.toHaveBeenCalled();
    });
});
