import { RouterView } from 'vue-router';

const agencyCard = {
    path: ':id',
    name: 'AgencyCard',
    component: () => import('src/pages/Route/Agency/Card/AgencyCard.vue'),
    redirect: { name: 'AgencySummary' },
    meta: {
        menu: ['AgencyBasicData', 'AgencyModes', 'AgencyWorkCenters', 'AgencyLog'],
    },
    children: [
        {
            name: 'AgencySummary',
            path: 'summary',
            meta: {
                title: 'summary',
                icon: 'view_list',
            },
            component: () => import('src/pages/Route/Agency/Card/AgencySummary.vue'),
        },
        {
            name: 'AgencyBasicData',
            path: 'basic-data',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () => import('pages/Route/Agency/Card/AgencyBasicData.vue'),
        },
        {
            path: 'workCenter',
            name: 'AgencyWorkCenterCard',
            redirect: { name: 'AgencyWorkCenters' },
            children: [
                {
                    path: '',
                    name: 'AgencyWorkCenters',
                    meta: {
                        icon: 'apartment',
                        title: 'workCenters',
                    },
                    component: () =>
                        import('src/pages/Route/Agency/Card/AgencyWorkcenter.vue'),
                },
            ],
        },
        {
            path: 'modes',
            name: 'AgencyModesCard',
            redirect: { name: 'AgencyModes' },
            children: [
                {
                    path: '',
                    name: 'AgencyModes',
                    meta: {
                        icon: 'format_list_bulleted',
                        title: 'modes',
                    },
                    component: () =>
                        import('src/pages/Route/Agency/Card/AgencyModes.vue'),
                },
            ],
        },
        {
            name: 'AgencyLog',
            path: 'log',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Route/Agency/Card/AgencyLog.vue'),
        },
    ],
};

export default {
    name: 'Agency',
    path: '/agency',
    meta: {
        title: 'agency',
        icon: 'garage_home',
        moduleName: 'Agency',
    },
    component: RouterView,
    redirect: { name: 'RouteMain' },
    children: [
        {
            name: 'AgencyMain',
            path: '',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'AgencyIndexMain' },
            children: [
                {
                    name: 'AgencyIndexMain',
                    path: '',
                    redirect: { name: 'AgencyList' },
                    component: () => import('src/pages/Route/Agency/AgencyList.vue'),
                    children: [
                        {
                            name: 'AgencyList',
                            path: 'list',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        agencyCard,
                    ],
                },
            ],
        },
    ],
};
