import { RouterView } from 'vue-router';

const claimCard = {
    name: 'ClaimCard',
    path: ':id',
    component: () => import('src/pages/Claim/Card/ClaimCard.vue'),
    redirect: { name: 'ClaimSummary' },
    meta: {
        menu: [
            'ClaimBasicData',
            'ClaimLines',
            'ClaimPhotos',
            'ClaimNotes',
            'ClaimDevelopment',
            'ClaimAction',
            'ClaimLog',
        ],
    },
    children: [
        {            
            path: 'summary',
            name: 'ClaimSummary',
            meta: {
                title: 'summary',
                icon: 'launch',
            },
            component: () => import('src/pages/Claim/Card/ClaimSummary.vue'),
        },
        {
            path: 'basic-data',
            name: 'ClaimBasicData',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
                acls: [{ model: 'Claim', props: 'findById', accessType: 'READ' }],
            },
            component: () => import('src/pages/Claim/Card/ClaimBasicData.vue'),
        },
        {
            path: 'lines',
            name: 'ClaimLines',
            meta: {
                title: 'lines',
                icon: 'vn:details',
            },
            component: () => import('src/pages/Claim/Card/ClaimLines.vue'),
        },
        {
            path: 'photos',
            name: 'ClaimPhotos',
            meta: {
                title: 'photos',
                icon: 'image',
            },
            component: () => import('src/pages/Claim/Card/ClaimPhoto.vue'),
        },
        {
            path: 'notes',
            name: 'ClaimNotes',
            meta: {
                title: 'notes',
                icon: 'draft',
            },
            component: () => import('src/pages/Claim/Card/ClaimNotes.vue'),
        },
        {
            path: 'development',
            name: 'ClaimDevelopment',
            meta: {
                title: 'development',
                icon: 'vn:traceability',
                acls: [
                    {
                        model: 'ClaimDevelopment',
                        props: '*',
                        accessType: 'WRITE',
                    },
                ],
            },
            component: () => import('src/pages/Claim/Card/ClaimDevelopment.vue'),
        },
        {
            path: 'action',
            name: 'ClaimAction',
            meta: {
                title: 'action',
                icon: 'vn:actions',
            },
            component: () => import('src/pages/Claim/Card/ClaimAction.vue'),
        },
        {
            path: 'log',
            name: 'ClaimLog',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Claim/Card/ClaimLog.vue'),
        },
    ],
}

export default {
    name: 'Claim',
    path: '/claim',
    meta: {
        title: 'claims',
        icon: 'vn:claims',
        moduleName: 'Claim',
        keyBinding: 'r',
        menu: ['ClaimList'],
    },
    component: RouterView,
    redirect: { name: 'ClaimMain' },
    children: [
        {
            name: 'ClaimMain',
            path: '',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'ClaimIndexMain' },
            children: [
                {
                    path: '',
                    name: 'ClaimIndexMain',
                    redirect: { name: 'ClaimList' },
                    component: () => import('src/pages/Claim/ClaimList.vue'),
                    children: [
                        {
                            name: 'ClaimList',
                            path: 'list',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        claimCard,
                    ],
                },
            ],
        },
    ],
};
