import { RouterView } from 'vue-router';

const invoiceInCard = {
    name: 'InvoiceInCard',
    path: ':id',
    component: () => import('src/pages/InvoiceIn/Card/InvoiceInCard.vue'),
    redirect: { name: 'InvoiceInSummary' },
    meta: {
        menu: [
            'InvoiceInBasicData',
            'InvoiceInVat',
            'InvoiceInDueDay',
            'InvoiceInIntrastat',
            'InvoiceInCorrective',
            'InvoiceInLog',
        ],
    },
    children: [
        {
            path: 'summary',
            name: 'InvoiceInSummary',
            meta: {
                title: 'summary',
                icon: 'view_list',
            },
            component: () => import('src/pages/InvoiceIn/Card/InvoiceInSummary.vue'),
        },
        {
            name: 'InvoiceInBasicData',
            path: 'basic-data',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () =>
                import('src/pages/InvoiceIn/Card/InvoiceInBasicData.vue'),
        },
        {
            name: 'InvoiceInVat',
            path: 'vat',
            meta: {
                title: 'vat',
                icon: 'vn:tax',
            },
            component: () => import('src/pages/InvoiceIn/Card/InvoiceInVat.vue'),
        },
        {
            name: 'InvoiceInDueDay',
            path: 'due-day',
            meta: {
                title: 'dueDay',
                icon: 'vn:calendar',
            },
            component: () =>
                import('src/pages/InvoiceIn/Card/InvoiceInDueDay.vue'),
        },
        {
            name: 'InvoiceInIntrastat',
            path: 'intrastat',
            meta: {
                title: 'intrastat',
                icon: 'vn:lines',
            },
            component: () =>
                import('src/pages/InvoiceIn/Card/InvoiceInIntrastat.vue'),
        },
        {
            name: 'InvoiceInCorrective',
            path: 'corrective',
            meta: {
                title: 'corrective',
                icon: 'attachment',
            },
            component: () =>
                import('src/pages/InvoiceIn/Card/InvoiceInCorrective.vue'),
        },
        {
            name: 'InvoiceInLog',
            path: 'log',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/InvoiceIn/Card/InvoiceInLog.vue'),
        },
    ],
};

export default {    
    name: 'InvoiceIn',
    path: '/invoice-in',
    meta: {
        title: 'invoiceIns',
        icon: 'vn:invoice-in',
        moduleName: 'InvoiceIn',
        menu: ['InvoiceInList', 'InvoiceInSerial'],
    },
    component: RouterView,
    redirect: { name: 'InvoiceInMain' },
    children: [
        {            
            name: 'InvoiceInMain',
            path: '',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'InvoiceInIndexMain' },
            children: [
                {
                    path: '',
                    name: 'InvoiceInIndexMain',
                    redirect: { name: 'InvoiceInList' },
                    component: () => import('src/pages/InvoiceIn/InvoiceInList.vue'),
                    children: [
                        {
                            name: 'InvoiceInList',                    
                            path: 'list',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        invoiceInCard,
                    ],
                },
                {
                    path: 'create',
                    name: 'InvoiceInCreare',
                    meta: {
                        title: 'invoiceInCreate',
                        icon: 'create',
                    },
                    component: () => import('src/pages/InvoiceIn/InvoiceInCreate.vue'),
                },
                {
                    path: 'serial',
                    name: 'InvoiceInSerial',
                    meta: {
                        title: 'serial',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/InvoiceIn/Serial/InvoiceInSerial.vue'),
                },
            ],
        },
    ],
};