import { RouterView } from 'vue-router';

const orderCard = {
    name: 'OrderCard',
    path: ':id',
    component: () => import('src/pages/Order/Card/OrderCard.vue'),
    redirect: { name: 'OrderSummary' },
    meta: {
        menu: [
            'OrderBasicData',
            'OrderCatalog',
            'OrderVolume',
            'OrderLines',
        ],
    },
    children: [
        {
            path: 'summary',
            name: 'OrderSummary',
            meta: {
                title: 'summary',
                icon: 'launch',
            },
            component: () => import('src/pages/Order/Card/OrderSummary.vue'),
        },
        {
            path: 'basic-data',
            name: 'OrderBasicData',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () => import('src/pages/Order/Card/OrderBasicData.vue'),
        },
        {
            path: 'catalog',
            name: 'OrderCatalog',
            meta: {
                title: 'catalog',
                icon: 'vn:basket',
            },
            component: () => import('src/pages/Order/Card/OrderCatalog.vue'),
        },
        {
            path: 'volume',
            name: 'OrderVolume',
            meta: {
                title: 'volume',
                icon: 'vn:volume',
            },
            component: () => import('src/pages/Order/Card/OrderVolume.vue'),
        },
        {
            path: 'line',
            name: 'OrderLines',
            meta: {
                title: 'lines',
                icon: 'vn:lines',
            },
            component: () => import('src/pages/Order/Card/OrderLines.vue'),
        },
    ],
};

export default {
    name: 'Order',
    path: '/order',
    meta: {
        title: 'order',
        icon: 'vn:basket',
        moduleName: 'Order',
        keyBinding: 'o',
        menu: ['OrderList'],
    },
    component: RouterView,
    redirect: { name: 'OrderMain' },
    children: [
        {
            name: 'OrderMain',
            path: '',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'OrderIndexMain' },
            children: [
                {
                    path: '',
                    name: 'OrderIndexMain',            
                    redirect: { name: 'OrderList' },
                    component: () => import('src/pages/Order/OrderList.vue'),
                    children: [
                        {
                            name: 'OrderList',
                            path: 'list',
                            meta: {
                                title: 'orderList',
                                icon: 'view_list',
                            },
                        },
                        orderCard,
                    ],
                },
                {
                    path: 'create',
                    name: 'OrderCreate',
                    meta: {
                        title: 'orderCreate',
                        icon: 'add',
                    },
                    component: () => import('src/pages/Order/OrderList.vue'),
                },
            ],
        },
    ],
};