import { RouterView } from 'vue-router';

export default {
    path: '/supplier',
    name: 'Supplier',
    meta: {
        title: 'suppliers',
        icon: 'vn:supplier',
        moduleName: 'Supplier',
        keyBinding: 'p',
    },
    component: RouterView,
    redirect: { name: 'SupplierMain' },
    menus: {
        main: ['SupplierList'],
        card: [
            'SupplierBasicData',
            'SupplierFiscalData',
            'SupplierBillingData',
            'SupplierLog',
            'SupplierAccounts',
            'SupplierContacts',
            'SupplierAddresses',
            'SupplierBalance',
            'SupplierConsumption',
            'SupplierAgencyTerm',
            'SupplierDms',
        ],
    },
    children: [
        {
            path: '',
            name: 'SupplierMain',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'SupplierList' },
            children: [
                {
                    path: 'list',
                    name: 'SupplierList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Supplier/SupplierList.vue'),
                },
                {
                    path: 'create',
                    name: 'SupplierCreate',
                    meta: {
                        title: 'supplierCreate',
                        icon: 'add',
                    },
                    component: () => import('src/pages/Supplier/SupplierCreate.vue'),
                },
            ],
        },
        {
            name: 'SupplierCard',
            path: ':id',
            component: () => import('src/pages/Supplier/Card/SupplierCard.vue'),
            redirect: { name: 'SupplierSummary' },
            children: [
                {
                    name: 'SupplierSummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierSummary.vue'),
                },
                {
                    path: 'basic-data',
                    name: 'SupplierBasicData',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierBasicData.vue'),
                },
                {
                    path: 'fiscal-data',
                    name: 'SupplierFiscalData',
                    meta: {
                        title: 'fiscalData',
                        icon: 'vn:dfiscales',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierFiscalData.vue'),
                },
                {
                    path: 'billing-data',
                    name: 'SupplierBillingData',
                    meta: {
                        title: 'billingData',
                        icon: 'vn:payment',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierBillingData.vue'),
                },
                {
                    path: 'log',
                    name: 'SupplierLog',
                    meta: {
                        title: 'log',
                        icon: 'vn:History',
                    },
                    component: () => import('src/pages/Supplier/Card/SupplierLog.vue'),
                },
                {
                    path: 'account',
                    name: 'SupplierAccounts',
                    meta: {
                        title: 'accounts',
                        icon: 'vn:credit',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierAccounts.vue'),
                },
                {
                    path: 'contact',
                    name: 'SupplierContacts',
                    meta: {
                        title: 'contacts',
                        icon: 'contact_phone',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierContacts.vue'),
                },
                {
                    path: 'address',
                    name: 'SupplierAddresses',
                    meta: {
                        title: 'addresses',
                        icon: 'vn:delivery',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierAddresses.vue'),
                },
                {
                    path: 'address/create',
                    name: 'SupplierAddressesCreate',
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierAddressesCreate.vue'),
                },
                {
                    path: 'balance',
                    name: 'SupplierBalance',
                    meta: {
                        title: 'balance',
                        icon: 'balance',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierBalance.vue'),
                },
                {
                    path: 'consumption',
                    name: 'SupplierConsumption',
                    meta: {
                        title: 'consumption',
                        icon: 'show_chart',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierConsumption.vue'),
                },
                {
                    path: 'agency-term',
                    name: 'SupplierAgencyTerm',
                    meta: {
                        title: 'agencyTerm',
                        icon: 'vn:agency-term',
                    },
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierAgencyTerm.vue'),
                },
                {
                    path: 'dms',
                    name: 'SupplierDms',
                    meta: {
                        title: 'dms',
                        icon: 'smb_share',
                    },
                    component: () => import('src/pages/Supplier/Card/SupplierDms.vue'),
                },
                {
                    path: 'agency-term/create',
                    name: 'SupplierAgencyTermCreate',
                    component: () =>
                        import('src/pages/Supplier/Card/SupplierAgencyTermCreate.vue'),
                },
            ],
        },
    ],
};
