import { RouterView } from 'vue-router';

const travelCard = {
    name: 'TravelCard',
    path: ':id',
    component: () => import('src/pages/Travel/Card/TravelCard.vue'),
    redirect: { name: 'TravelSummary' },
    meta: {
        menu: ['TravelBasicData', 'TravelHistory', 'TravelThermographs'],
    },
    children: [
        {
            name: 'TravelSummary',
            path: 'summary',
            meta: {
                title: 'summary',
            },
            component: () => import('src/pages/Travel/Card/TravelSummary.vue'),
        },
        {
            name: 'TravelBasicData',
            path: 'basic-data',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () => import('src/pages/Travel/Card/TravelBasicData.vue'),
        },
        {
            name: 'TravelHistory',
            path: 'log',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Travel/Card/TravelLog.vue'),
        },
        {
            name: 'TravelThermographs',
            path: 'thermographs/:thermographId?',
            meta: {
                title: 'thermographs',
                icon: 'vn:thermometer',
            },
            redirect: {
                name: 'TravelThermographsIndex',
            },
            children: [
                {
                    name: 'TravelThermographsIndex',
                    path: 'index',
                    component: () =>
                        import('src/pages/Travel/Card/TravelThermographs.vue'),
                },
                {
                    name: 'TravelThermographsCreate',
                    path: 'create',
                    props: { viewAction: 'create' },
                    component: () =>
                        import(
                            'src/pages/Travel/Card/TravelThermographsForm.vue'
                        ),
                },
                {
                    name: 'TravelThermographsEdit',
                    path: 'edit',
                    props: { viewAction: 'edit' },
                    component: () =>
                        import(
                            'src/pages/Travel/Card/TravelThermographsForm.vue'
                        ),
                },
            ],
        },
    ]
};

export default {
    path: '/travel',
    name: 'Travel',
    meta: {
        title: 'travel',
        icon: 'local_airport',
        moduleName: 'Travel',
        menu: ['TravelList', 'ExtraCommunity'],
    },
    component: RouterView,
    redirect: { name: 'TravelMain' },
    children: [
        {
            path: '',
            name: 'TravelMain',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'TravelIndexMain' },
            children: [
                {
                    path: '',
                    name: 'TravelIndexMain',
                    redirect: { name: 'TravelList' },
                    component: () => import('src/pages/Travel/TravelList.vue'),
                    children: [
                        {
                            name: 'TravelList',
                            path: 'list',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        travelCard,
                    ],
                },
                {
                    path: 'extra-community',
                    name: 'ExtraCommunity',
                    meta: {
                        title: 'extraCommunity',
                        icon: 'vn:shipment',
                    },
                    component: () => import('src/pages/Travel/ExtraCommunity.vue'),
                },
                {
                    path: 'create',
                    name: 'TravelCreate',
                    meta: {
                        title: 'travelCreate',
                        icon: 'add',
                    },
                    component: () => import('src/pages/Travel/TravelCreate.vue'),
                },
            ],
        },
    ],
};
