// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
// -- This is a parent command --
// Cypress.Commands.add("login", (email, password) => { ... })
//
//
// -- This is a child command --
// Cypress.Commands.add("drag", { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add("dismiss", { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This is will overwrite an existing command --
// Cypress.Commands.overwrite("visit", (originalFn, url, options) => { ... })

// DO NOT REMOVE
// Imports Quasar Cypress AE predefined commands
// import { registerCommands } from '@quasar/quasar-app-extension-testing-e2e-cypress';
Cypress.Commands.add('waitUntil', { prevSubject: 'optional' }, require('./waitUntil'));
Cypress.Commands.add('resetDB', () => {
    cy.exec('pnpm run resetDatabase');
});
Cypress.Commands.add('login', (user) => {
    //cy.visit('/#/login');
    cy.request({
        method: 'POST',
        url: '/api/accounts/login',
        body: {
            user: user,
            password: 'nightmare',
        },
    }).then((response) => {
        window.localStorage.setItem('token', response.body.token);
        cy.request({
            method: 'GET',
            url: '/api/VnUsers/ShareToken',
            headers: {
                Authorization: window.localStorage.getItem('token'),
            },
        }).then(({ body }) => {
            window.localStorage.setItem('tokenMultimedia', body.multimediaToken.id);
        });
    });
});

Cypress.Commands.add('domContentLoad', (element, timeout = 5000) => {
    cy.waitUntil(() => cy.document().then((doc) => doc.readyState === 'complete'));
});
Cypress.Commands.add('waitForElement', (element, timeout = 5000) => {
    cy.get(element, { timeout }).should('be.visible').and('not.be.disabled');
});

Cypress.Commands.add('getValue', (selector) => {
    cy.get(selector).then(($el) => {
        if ($el.find('.q-checkbox__inner').length > 0) {
            return cy.get(selector + '.q-checkbox__inner');
        }
        // Si es un QSelect
        if ($el.find('.q-select__dropdown-icon').length) {
            return cy
                .get(
                    selector +
                        '> .q-field > .q-field__inner > .q-field__control > .q-field__control-container > .q-field__native > input',
                )
                .invoke('val');
        }
        // Si es un QSelect
        if ($el.find('span').length) {
            return cy.get(selector + ' span').then(($span) => {
                return $span[0].innerText;
            });
        }
        // Puedes añadir un log o lanzar un error si el elemento no es reconocido
        cy.log('Elemento no soportado');
    });
});

// Fill Inputs
Cypress.Commands.add('selectOption', (selector, option, timeout = 5000) => {
    cy.waitForElement(selector, timeout);
    cy.get(selector).click();
    cy.get(selector).invoke('data', 'url').as('dataUrl');
    cy.get(selector)
        .clear()
        .type(option)
        .then(() => {
            cy.get('.q-menu', { timeout })
                .should('be.visible') // Asegurarse de que el menú está visible
                .and('exist') // Verificar que el menú existe
                .then(() => {
                    cy.get('@dataUrl').then((url) => {
                        if (url) {
                            // Esperar a que el menú no esté visible (desaparezca)
                            cy.get('.q-menu').should('not.be.visible');
                            // Ahora esperar a que el menú vuelva a aparecer
                            cy.get('.q-menu').should('be.visible').and('exist');
                        }
                    });
                });
        });

    // Finalmente, seleccionar la opción deseada
    cy.get('.q-menu:visible') // Asegurarse de que estamos dentro del menú visible
        .find('.q-item') // Encontrar los elementos de las opciones
        .contains(option) // Verificar que existe una opción que contenga el texto deseado
        .click(); // Hacer clic en la opción
});

Cypress.Commands.add('countSelectOptions', (selector, option) => {
    cy.waitForElement(selector);
    cy.get(selector).click({ force: true });
    cy.get('.q-menu .q-item').should('have.length', option);
});

Cypress.Commands.add('fillInForm', (obj, form = '.q-form > .q-card') => {
    cy.waitForElement(form);
    cy.get(`${form} input`).each(([el]) => {
        cy.wrap(el)
            .invoke('attr', 'aria-label')
            .then((ariaLabel) => {
                const field = obj[ariaLabel];
                if (!field) return;

                const { type, val } = field;
                switch (type) {
                    case 'select':
                        cy.selectOption(el, val);
                        break;
                    case 'date':
                        cy.get(el).type(val.split('-').join(''));
                        break;
                    case 'time':
                        cy.get(el).click();
                        cy.get('.q-time .q-time__clock').contains(val.h).click();
                        cy.get('.q-time .q-time__clock').contains(val.m).click();
                        cy.get('.q-time .q-time__link').contains(val.x).click();
                        break;
                    default:
                        cy.wrap(el).type(val);
                        break;
                }
            });
    });
});

Cypress.Commands.add('checkOption', (selector) => {
    cy.get(selector).find('.q-checkbox__inner').click();
});

// Global buttons
Cypress.Commands.add('saveCard', () => {
    const dropdownArrow = '.q-btn-dropdown__arrow-container > .q-btn__content > .q-icon';
    cy.get('#st-actions').then(($el) => {
        if ($el.find(dropdownArrow).length) cy.get(dropdownArrow).click();
    });
    cy.get('[title="Save"]').click();
});

Cypress.Commands.add('resetCard', () => {
    cy.get('[title="Reset"]').click();
});
Cypress.Commands.add('removeCard', () => {
    cy.get('[title="Remove"]').click();
});
Cypress.Commands.add('addCard', () => {
    cy.waitForElement('tbody');
    cy.waitForElement('.q-page-sticky > div > .q-btn');
    cy.get('.q-page-sticky > div > .q-btn').click();
});
Cypress.Commands.add('clickConfirm', () => {
    cy.waitForElement('.q-dialog__inner > .q-card');
    cy.get('.q-card__actions > .q-btn--unelevated > .q-btn__content > .block').click();
});

Cypress.Commands.add('notificationHas', (selector, text) => {
    cy.get(selector).should('have.text', text);
});

Cypress.Commands.add('selectRows', (rows) => {
    rows.forEach((row) => {
        cy.get('.q-table .q-virtual-scroll__content tr .q-checkbox__inner')
            .eq(row - 1)
            .click();
    });
});

Cypress.Commands.add('fillRow', (rowSelector, data) => {
    // Usar el selector proporcionado para obtener la fila deseada
    cy.waitForElement('tbody');
    cy.get(rowSelector).as('currentRow');

    data.forEach((value, index) => {
        if (value === null) return;
        cy.get('@currentRow')
            .find('td')
            .eq(index)
            .then((td) => {
                if (td.find('.q-select__dropdown-icon').length) {
                    cy.selectOption(td, value);
                } else if (td.find('.q-checkbox__inner').length && value) {
                    cy.checkOption(td);
                } else if (td.find('input[type="text"]') && value)
                    cy.get(td).find('input').type(value);
            });
    });
});

Cypress.Commands.add('addRow', () => {
    cy.waitForElement('tbody');
    cy.get('.q-page-sticky > div > .q-btn > .q-btn__content').click();
});

Cypress.Commands.add('validateRow', (rowSelector, expectedValues) => {
    cy.waitForElement('tbody');
    cy.get(rowSelector).within(() => {
        for (const [index, value] of expectedValues.entries()) {
            cy.log('CHECKING ', index, value);
            if (value === undefined) continue;
            if (typeof value == 'boolean') {
                const prefix = value ? '' : 'not.';
                cy.getValue(`:nth-child(${index + 1})`).should(`${prefix}be.checked`);
                continue;
            }
            cy.getValue(`:nth-child(${index + 1})`).should('equal', value);
        }
    });
});

Cypress.Commands.add('removeRow', (rowIndex) => {
    const trEls = 'tbody > tr:visible';
    let rowsBefore;
    cy.get('tbody > tr')
        .its('length')
        .then((length) => {
            cy.get(`${trEls} .q-checkbox`)
                .eq(rowIndex - 1)
                .click();
            cy.removeCard();
            cy.get('.q-dialog button').eq(2).click();
            rowsBefore = length;
        })
        .then(() => {
            // Check the existence of tbody before performing the second assertion.
            cy.get('tbody').then(($tbody) => {
                if ($tbody.length > 0)
                    cy.get('tbody > tr').should('have.length', rowsBefore - 1);
            });
        });
});
Cypress.Commands.add('openListSummary', (row) => {
    cy.get('.card-list-body .actions .q-btn:nth-child(2)').eq(row).click();
});

Cypress.Commands.add('openRightMenu', (element) => {
    if (element) cy.waitForElement(element);
    cy.get('[data-cy="toggle-right-drawer"]').click();
});

Cypress.Commands.add('openLeftMenu', (element) => {
    if (element) cy.waitForElement(element);
    cy.get('.q-toolbar > .q-btn--round.q-btn--dense > .q-btn__content > .q-icon').click();
});

Cypress.Commands.add('clearSearchbar', (element) => {
    if (element) cy.waitForElement(element);
    cy.get('[data-cy="vn-searchbar"]').clear();
});

Cypress.Commands.add('typeSearchbar', (value) => {
    cy.get('[data-cy="vn-searchbar"]').type(value);
});

Cypress.Commands.add('validateContent', (selector, expectedValue) => {
    cy.get(selector).should('have.text', expectedValue);
});

Cypress.Commands.add('openActionDescriptor', (opt) => {
    cy.openActionsDescriptor();
    const listItem = '[role="menu"] .q-list .q-item';
    cy.contains(listItem, opt).click();
    1;
});

Cypress.Commands.add('openActionsDescriptor', () => {
    cy.get('[data-cy="descriptor-more-opts"]').click();
});

Cypress.Commands.add('clickButtonsDescriptor', (id) => {
    cy.get(`.actions > .q-card__actions> .q-btn:nth-child(${id})`)
        .invoke('removeAttr', 'target')
        .click();
});

Cypress.Commands.add('openActionDescriptor', (opt) => {
    cy.openActionsDescriptor();
    const listItem = '[role="menu"] .q-list .q-item';
    cy.contains(listItem, opt).click();
    1;
});

Cypress.Commands.add('clickButtonsDescriptor', (id) => {
    cy.get(`.actions > .q-card__actions> .q-btn:nth-child(${id})`)
        .invoke('removeAttr', 'target')
        .click();
});

Cypress.Commands.add('openActionDescriptor', (opt) => {
    cy.openActionsDescriptor();
    const listItem = '[role="menu"] .q-list .q-item';
    cy.contains(listItem, opt).click();
    1;
});

Cypress.Commands.add('clickButtonsDescriptor', (id) => {
    cy.get(`.actions > .q-card__actions> .q-btn:nth-child(${id})`)
        .invoke('removeAttr', 'target')
        .click();
});

Cypress.Commands.add('openUserPanel', () => {
    cy.get(
        '.column > .q-avatar > .q-avatar__content > .q-img > .q-img__container > .q-img__image',
    ).click();
});

Cypress.Commands.add('checkNotification', (text) => {
    cy.get('.q-notification')
        .should('be.visible')
        .last()
        .then(($lastNotification) => {
            if (!Cypress.$($lastNotification).text().includes(text))
                throw new Error(`Notification not found: "${text}"`);
        });
});

Cypress.Commands.add('openActions', (row) => {
    cy.get('tbody > tr').eq(row).find('.actions > .q-btn').click();
});

Cypress.Commands.add('checkValueForm', (id, search) => {
    cy.get(`.grid-create > :nth-child(${id}) `)
        .find('input')
        .should('have.value', search);
});

Cypress.Commands.add('checkValueSelectForm', (id, search) => {
    cy.get(
        `.grid-create > :nth-child(${id}) > .q-field > .q-field__inner > .q-field__control > .q-field__control-container > .q-field__native > .q-field__input`,
    ).should('have.value', search);
});

Cypress.Commands.add('searchByLabel', (label, value) => {
    cy.get(`[label="${label}"] > .q-field > .q-field__inner`).type(`${value}{enter}`);
});

Cypress.Commands.add('dataCy', (tag, attr = 'data-cy') => {
    return cy.get(`[${attr}="${tag}"]`);
});

Cypress.Commands.add('addBtnClick', () => {
    cy.get('.q-page-sticky > div > .q-btn > .q-btn__content > .q-icon')
        .should('exist')
        .and('be.visible')
        .click();
});
